import React from 'react';
import type { Tier } from '../App';
import type { Upgrades } from './GubbleStore';

type CardProps = {
  card: {
    winningNumbers: number[];
    fields: { value: number; scratched: boolean; won: number | null }[];
    tier: Tier | null;
  };
  setCard: React.Dispatch<React.SetStateAction<{
    winningNumbers: number[];
    fields: { value: number; scratched: boolean; won: number | null }[];
    tier: Tier | null;
  } | null>>;
  setMoney: React.Dispatch<React.SetStateAction<number>>;
  setGubblePoints: React.Dispatch<React.SetStateAction<number>>;
  upgrades?: Upgrades;
};

const Card: React.FC<CardProps> = ({ card, setCard, setMoney, setGubblePoints, upgrades }) => {
  const formatter = Intl.NumberFormat(
    'en', 
    { 'notation': 'compact' }
    )
  return (
    <div className="bg-gray-800 rounded-lg shadow-lg p-6 flex flex-col items-center mb-6 w-full max-w-md">
      <div className="mb-2 text-lg font-semibold text-gray-100">{card.tier?.name} Scratch Card</div>
      <div className="mb-4 flex gap-4 justify-center">
        {card.winningNumbers.map((num, i) => (
          <div key={i} className="w-12 h-12 flex items-center justify-center rounded-full bg-blue-900 text-blue-300 text-xl font-bold border-2 border-blue-700">
            {num}
          </div>
        ))}
      </div>
      <div className="grid grid-cols-3 gap-4 mb-2">
        {card.fields.map((field, idx) => (
          <button
            key={idx}
            className={`w-16 h-16 flex items-center justify-center rounded-lg border-2 text-2xl font-bold transition
              ${field.scratched ? (field.won ? 'bg-green-900 border-green-700 text-green-300' : 'bg-gray-700 border-gray-600 text-gray-400') : 'bg-yellow-900 border-yellow-700 text-yellow-300 hover:bg-yellow-800'}`}
            disabled={field.scratched}
            onMouseMove={() => {
              if (field.scratched) return;
              // Gubble point gain (with upgrade)
              if (Math.random() < (card.tier?.gubblePointChance ?? 0)) {
                setGubblePoints((g) => g + (upgrades?.gubbleDouble ? 2 : 1));
                return;
              }
              // Determine win amount
              let won = null;
              if (card.winningNumbers.includes(field.value)) {
                won = 0;
                if (idx < 2) won = Math.ceil((card.tier?.buyPrice ?? 0) * 0.5);
                else if (idx < 4) won = Math.ceil((card.tier?.buyPrice ?? 0) * 0.8);
                else won = Math.ceil((card.tier?.buyPrice ?? 0) * 1.2);
                // Apply upgrades
                if (upgrades?.allTripple) {
                  won = won * 2;
                } 
                if (upgrades?.evenDouble && field.value % 2 === 0) {
                  won = won * 2;
                } 
                if (upgrades?.oddDouble && field.value % 2 === 1) {
                  won = won * 2;
                }
              }
              setCard((prev) => {
                if (!prev) return prev;
                const newFields = prev.fields.map((f, i) => i === idx ? { ...f, scratched: true, won } : f);
                return { ...prev, fields: newFields };
              });
              if (won) setMoney((m) => m + won);
            }}
          >
            {field.scratched ? (
              <span>{field.value}{field.won ? <span className="block text-xs font-normal text-green-300">+${formatter.format(field.won)}</span> : ''}</span>
            ) : (
              <span className="text-3xl select-none">?</span>
            )}
          </button>
        ))}
      </div>
      <div className="text-xs text-gray-400">Scratch each field one at a time. Winnings: 1-2 = 50%, 3-4 = 80%, 5-6 = 120% of card price.</div>
    </div>
  );
};

export type { CardProps };
export default React.memo(Card); 